summaryrefslogtreecommitdiffhomepage
path: root/src/gc.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/gc.c')
-rw-r--r--src/gc.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/gc.c b/src/gc.c
index 3af163010..9286f361b 100644
--- a/src/gc.c
+++ b/src/gc.c
@@ -1,5 +1,5 @@
/*
** gc.c - garbage collector for RiteVM
**
** See Copyright Notice in mruby.h
*/
@@ -24,7 +24,7 @@
/*
= Tri-color Incremental Garbage Collection
- RiteVM's GC is Tri-color Incremental GC with Mark & Sweep.
+ mruby's GC is Tri-color Incremental GC with Mark & Sweep.
Algorithm details are omitted.
Instead, the part about the implementation described below.
@@ -61,7 +61,7 @@
= Write Barrier
- RiteVM implementer, C extension library writer must write a write
+ mruby implementer, C extension library writer must write a write
barrier when writing a pointer to an object on object's field.
Two different write barrier:
@@ -1,5 +1,5 @@
/*
-** gc.c - garbage collector for RiteVM
+** gc.c - garbage collector for mruby
**
** See Copyright Notice in mruby.h